@@ -21,7 +21,6 @@ from eventlet import semaphore
 from eventlet import wsgi
 from eventlet.green import socket
 from eventlet.support import get_errno
-import six
 
 # Python 2's utf8 decoding is more lenient than we'd like
 # In order to pass autobahn's testsuite we need stricter validation
@@ -37,7 +36,7 @@ for _mod in ('wsaccel.utf8validator', 'autobahn.utf8validator'):
     else:
         break
 
-ACCEPTABLE_CLIENT_ERRORS = set((errno.ECONNRESET, errno.EPIPE))
+ACCEPTABLE_CLIENT_ERRORS = {errno.ECONNRESET, errno.EPIPE, errno.ESHUTDOWN}
 DEFAULT_MAX_FRAME_LENGTH = 8 << 20
 
 __all__ = ["WebSocketWSGI", "WebSocket"]
@@ -62,7 +61,7 @@ class BadRequest(Exception):
         self.headers = headers
 
 
-class WebSocketWSGI(object):
+class WebSocketWSGI:
     """Wraps a websocket handler function in a WSGI application.
 
     Use it like this::
@@ -135,7 +134,7 @@ class WebSocketWSGI(object):
 
         try:
             self.handler(ws)
-        except socket.error as e:
+        except OSError as e:
             if get_errno(e) not in ACCEPTABLE_CLIENT_ERRORS:
                 raise
         # Make sure we send the closing frame
@@ -188,18 +187,18 @@ class WebSocketWSGI(object):
                 b"HTTP/1.1 101 Web Socket Protocol Handshake\r\n"
                 b"Upgrade: WebSocket\r\n"
                 b"Connection: Upgrade\r\n"
-                b"WebSocket-Origin: " + six.b(environ.get('HTTP_ORIGIN')) + b"\r\n"
-                b"WebSocket-Location: " + six.b(location) + b"\r\n\r\n"
+                b"WebSocket-Origin: " + environ.get('HTTP_ORIGIN').encode() + b"\r\n"
+                b"WebSocket-Location: " + location.encode() + b"\r\n\r\n"
             )
         elif self.protocol_version == 76:
             handshake_reply = (
                 b"HTTP/1.1 101 WebSocket Protocol Handshake\r\n"
                 b"Upgrade: WebSocket\r\n"
                 b"Connection: Upgrade\r\n"
-                b"Sec-WebSocket-Origin: " + six.b(environ.get('HTTP_ORIGIN')) + b"\r\n"
+                b"Sec-WebSocket-Origin: " + environ.get('HTTP_ORIGIN').encode() + b"\r\n"
                 b"Sec-WebSocket-Protocol: " +
-                six.b(environ.get('HTTP_SEC_WEBSOCKET_PROTOCOL', 'default')) + b"\r\n"
-                b"Sec-WebSocket-Location: " + six.b(location) + b"\r\n"
+                environ.get('HTTP_SEC_WEBSOCKET_PROTOCOL', 'default').encode() + b"\r\n"
+                b"Sec-WebSocket-Location: " + location.encode() + b"\r\n"
                 b"\r\n" + response
             )
         else:  # pragma NO COVER
@@ -266,14 +265,14 @@ class WebSocketWSGI(object):
             return None
         parts = []
         for name, config in parsed_extensions.items():
-            ext_parts = [six.b(name)]
+            ext_parts = [name.encode()]
             for key, value in config.items():
                 if value is False:
                     pass
                 elif value is True:
-                    ext_parts.append(six.b(key))
+                    ext_parts.append(key.encode())
                 else:
-                    ext_parts.append(six.b("%s=%s" % (key, str(value))))
+                    ext_parts.append(("%s=%s" % (key, str(value))).encode())
             parts.append(b"; ".join(ext_parts))
         return b", ".join(parts)
 
@@ -309,13 +308,13 @@ class WebSocketWSGI(object):
                     break
 
         key = environ['HTTP_SEC_WEBSOCKET_KEY']
-        response = base64.b64encode(sha1(six.b(key) + PROTOCOL_GUID).digest())
+        response = base64.b64encode(sha1(key.encode() + PROTOCOL_GUID).digest())
         handshake_reply = [b"HTTP/1.1 101 Switching Protocols",
                            b"Upgrade: websocket",
                            b"Connection: Upgrade",
                            b"Sec-WebSocket-Accept: " + response]
         if negotiated_protocol:
-            handshake_reply.append(b"Sec-WebSocket-Protocol: " + six.b(negotiated_protocol))
+            handshake_reply.append(b"Sec-WebSocket-Protocol: " + negotiated_protocol.encode())
 
         parsed_extensions = {}
         extensions = self._parse_extension_header(environ.get("HTTP_SEC_WEBSOCKET_EXTENSIONS"))
@@ -349,7 +348,7 @@ class WebSocketWSGI(object):
         return int(out) // spaces
 
 
-class WebSocket(object):
+class WebSocket:
     """A websocket object that handles the details of
     serialization/deserialization to the socket.
 
@@ -399,10 +398,10 @@ class WebSocket(object):
 
         As per the dataframing section (5.3) for the websocket spec
         """
-        if isinstance(message, six.text_type):
+        if isinstance(message, str):
             message = message.encode('utf-8')
-        elif not isinstance(message, six.binary_type):
-            message = six.b(str(message))
+        elif not isinstance(message, bytes):
+            message = str(message).encode()
         packed = b"\x00" + message + b"\xFF"
         return packed
 
@@ -417,7 +416,7 @@ class WebSocket(object):
         end_idx = 0
         buf = self._buf
         while buf:
-            frame_type = six.indexbytes(buf, 0)
+            frame_type = buf[0]
             if frame_type == 0:
                 # Normal message.
                 end_idx = buf.find(b"\xFF")
@@ -427,7 +426,7 @@ class WebSocket(object):
                 buf = buf[end_idx + 1:]
             elif frame_type == 255:
                 # Closing handshake.
-                assert six.indexbytes(buf, 1) == 0, "Unexpected closing handshake: %r" % buf
+                assert buf[1] == 0, "Unexpected closing handshake: %r" % buf
                 self.websocket_closed = True
                 break
             else:
@@ -475,7 +474,7 @@ class WebSocket(object):
         if self.version == 76 and not self.websocket_closed:
             try:
                 self.socket.sendall(b"\xff\x00")
-            except SocketError:
+            except OSError:
                 # Sometimes, like when the remote side cuts off the connection,
                 # we don't care about this.
                 if not ignore_send_errors:  # pragma NO COVER
@@ -488,7 +487,7 @@ class WebSocket(object):
         try:
             self._send_closing_frame(True)
             self.socket.shutdown(True)
-        except SocketError as e:
+        except OSError as e:
             if e.errno != errno.ENOTCONN:
                 self.log.write('{ctx} socket shutdown error: {e}'.format(ctx=self.log_context, e=e))
         finally:
@@ -501,7 +500,7 @@ class ConnectionClosedError(Exception):
 
 class FailedConnectionError(Exception):
     def __init__(self, status, message):
-        super(FailedConnectionError, self).__init__(status, message)
+        super().__init__(status, message)
         self.message = message
         self.status = status
 
@@ -513,7 +512,7 @@ class ProtocolError(ValueError):
 class RFC6455WebSocket(WebSocket):
     def __init__(self, sock, environ, version=13, protocol=None, client=False, extensions=None,
                  max_frame_length=DEFAULT_MAX_FRAME_LENGTH):
-        super(RFC6455WebSocket, self).__init__(sock, environ, version)
+        super().__init__(sock, environ, version)
         self.iterator = self._iter_frames()
         self.client = client
         self.protocol = protocol
@@ -524,7 +523,7 @@ class RFC6455WebSocket(WebSocket):
         self.max_frame_length = max_frame_length
         self._remote_close_data = None
 
-    class UTF8Decoder(object):
+    class UTF8Decoder:
         def __init__(self):
             if utf8validator:
                 self.validator = utf8validator.Utf8Validator()
@@ -593,7 +592,7 @@ class RFC6455WebSocket(WebSocket):
             data = data + d
         return data
 
-    class Message(object):
+    class Message:
         def __init__(self, opcode, max_frame_length, decoder=None, decompressor=None):
             self.decoder = decoder
             self.data = []
@@ -624,7 +623,7 @@ class RFC6455WebSocket(WebSocket):
         if length is None:
             length = len(data)
         cnt = range(length)
-        return b''.join(six.int2byte(six.indexbytes(data, i) ^ mask[(offset + i) % 4]) for i in cnt)
+        return b''.join(bytes((data[i] ^ mask[(offset + i) % 4],)) for i in cnt)
 
     def _handle_control_frame(self, opcode, data):
         if opcode == 8:  # connection close
@@ -760,13 +759,23 @@ class RFC6455WebSocket(WebSocket):
     def _pack_message(self, message, masked=False,
                       continuation=False, final=True, control_code=None):
         is_text = False
-        if isinstance(message, six.text_type):
+        if isinstance(message, str):
             message = message.encode('utf-8')
             is_text = True
 
         compress_bit = 0
         compressor = self._get_permessage_deflate_enc()
-        if message and compressor:
+        # Control frames are identified by opcodes where the most significant
+        # bit of the opcode is 1.  Currently defined opcodes for control frames
+        # include 0x8 (Close), 0x9 (Ping), and 0xA (Pong).  Opcodes 0xB-0xF are
+        # reserved for further control frames yet to be defined.
+        # https://datatracker.ietf.org/doc/html/rfc6455#section-5.5
+        is_control_frame = (control_code or 0) & 8
+        # An endpoint MUST NOT set the "Per-Message Compressed" bit of control
+        # frames and non-first fragments of a data message.  An endpoint
+        # receiving such a frame MUST _Fail the WebSocket Connection_.
+        # https://datatracker.ietf.org/doc/html/rfc7692#section-6.1
+        if message and compressor and not is_control_frame:
             message = compressor.compress(message)
             message += compressor.flush(zlib.Z_SYNC_FLUSH)
             assert message[-4:] == b"\x00\x00\xff\xff"
@@ -799,7 +808,7 @@ class RFC6455WebSocket(WebSocket):
             # NOTE: RFC6455 states:
             # A server MUST NOT mask any frames that it sends to the client
             rand = Random(time.time())
-            mask = [rand.getrandbits(8) for _ in six.moves.xrange(4)]
+            mask = [rand.getrandbits(8) for _ in range(4)]
             message = RFC6455WebSocket._apply_mask(message, mask, length)
             maskdata = struct.pack('!BBBB', *mask)
         else:
@@ -827,14 +836,14 @@ class RFC6455WebSocket(WebSocket):
         if self.version in (8, 13) and not self.websocket_closed:
             if close_data is not None:
                 status, msg = close_data
-                if isinstance(msg, six.text_type):
+                if isinstance(msg, str):
                     msg = msg.encode('utf-8')
                 data = struct.pack('!H', status) + msg
             else:
                 data = ''
             try:
                 self.send(data, control_code=8)
-            except SocketError:
+            except OSError:
                 # Sometimes, like when the remote side cuts off the connection,
                 # we don't care about this.
                 if not ignore_send_errors:  # pragma NO COVER
@@ -847,7 +856,7 @@ class RFC6455WebSocket(WebSocket):
         try:
             self._send_closing_frame(close_data=close_data, ignore_send_errors=True)
             self.socket.shutdown(socket.SHUT_WR)
-        except SocketError as e:
+        except OSError as e:
             if e.errno != errno.ENOTCONN:
                 self.log.write('{ctx} socket shutdown error: {e}'.format(ctx=self.log_context, e=e))
         finally:
